@@ -34,6 +34,7 @@
 #include "thlayoutln.h"
 #include "thsymbolset.h"
 #include "thlocale.h"
+#include "thlayoutclr.h"
 #include <list>
 
 /**
@@ -93,6 +94,8 @@ enum {
 	TT_LAYOUT_SKETCHES = 2049,
 	TT_LAYOUT_NORTH = 2050,
   TT_LAYOUT_MAP_IMAGE = 2051,
+  TT_LAYOUT_GRID_COORDS = 2052,
+  TT_LAYOUT_SYMBOL_COLOR = 2053,
 };
 
 
@@ -120,6 +123,30 @@ static const thstok thtt_layout_grid[] = {
 };
 
 
+/**
+ * Layout grid tokens.
+ */
+
+enum {
+  TT_LAYOUT_GRIDCOORDS_UNKNOWN = 0,
+  TT_LAYOUT_GRIDCOORDS_OFF,
+  TT_LAYOUT_GRIDCOORDS_BORDER,
+  TT_LAYOUT_GRIDCOORDS_ALL,
+};
+
+
+/**
+ * Layout grid token table.
+ */
+ 
+static const thstok thtt_layout_gridcoords[] = {
+  {"all", TT_LAYOUT_GRIDCOORDS_ALL},
+  {"border", TT_LAYOUT_GRIDCOORDS_BORDER},
+  {"off", TT_LAYOUT_GRIDCOORDS_OFF},
+  {NULL, TT_LAYOUT_GRIDCOORDS_UNKNOWN}
+};
+
+
 /**
  * Layout map-item token table.
  */
@@ -268,6 +295,7 @@ enum {
   TT_LAYOUT_CODE_SYMBOL_ASSIGN,
   TT_LAYOUT_CODE_SYMBOL_HIDE,
   TT_LAYOUT_CODE_SYMBOL_SHOW,
+  TT_LAYOUT_CODE_SYMBOL_COLOR,
   TT_LAYOUT_CODE_MAP_ITEM,
 };
 
@@ -317,6 +345,7 @@ enum {
   TT_LAYOUT_COLOR_MAP_FG,
   TT_LAYOUT_COLOR_PREVIEW_BELOW,
   TT_LAYOUT_COLOR_PREVIEW_ABOVE,
+  TT_LAYOUT_COLOR_LABELS,
 };
 
 
@@ -325,6 +354,7 @@ enum {
  */
  
 static const thstok thtt_layout_color[] = {
+  {"labels", TT_LAYOUT_COLOR_LABELS},
   {"map-bg", TT_LAYOUT_COLOR_MAP_BG},
   {"map-fg", TT_LAYOUT_COLOR_MAP_FG},
   {"preview-above", TT_LAYOUT_COLOR_PREVIEW_ABOVE},
@@ -385,7 +415,7 @@ class thlayout_copy_src {
 
   public:
   
-  char * srcn;
+  const char * srcn;
   thlayout * srcptr;
   class thlayout_copy_src * next_src;
   thlayout_copy_src () : srcn(NULL), srcptr(NULL), next_src(NULL) {};
@@ -413,6 +443,7 @@ static const thstok thtt_layout_opt[] = {
   {"endcode",TT_LAYOUT_ENDCODE},
   {"exclude-pages",TT_LAYOUT_EXCLUDE_PAGES},
   {"grid",TT_LAYOUT_GRID},
+  {"grid-coords",TT_LAYOUT_GRID_COORDS},
   {"grid-origin",TT_LAYOUT_GRID_ORIGIN},
   {"grid-size",TT_LAYOUT_GRID_SIZE},
   {"language",TT_LAYOUT_LANG},
@@ -445,6 +476,8 @@ static const thstok thtt_layout_opt[] = {
   {"surface-opacity",TT_LAYOUT_SURFACE_OPACITY},
   {"survey-level",TT_LAYOUT_SURVEY_LEVEL},
   {"symbol-assign", TT_LAYOUT_SYMBOL_ASSIGN},
+  {"symbol-color", TT_LAYOUT_SYMBOL_COLOR},
+  {"symbol-colour", TT_LAYOUT_SYMBOL_COLOR},
   {"symbol-hide", TT_LAYOUT_SYMBOL_HIDE},
   {"symbol-set", TT_LAYOUT_SYMBOL_DEFAULTS},
   {"symbol-show", TT_LAYOUT_SYMBOL_SHOW},
@@ -455,18 +488,6 @@ static const thstok thtt_layout_opt[] = {
 };
 
 
-/**
- * layout color class.
- */
-
-struct thlayout_color {
-  double R, G, B;
-  int defined;
-  void parse(char * str);
-  thlayout_color() : R(1.0), G(1.0), B(1.0), defined(false) {}
-};
-
-
 /**
  * layout color value class
  */
@@ -484,7 +505,7 @@ typedef std::list<thlayout_color_value> thlayout_ct;
 
 struct thlayout_map_image {
   double m_x, m_y;
-  char * m_fn;
+  const char * m_fn;
   int m_align;
   thlayout_map_image() : m_x(0.0), m_y(0.0), m_fn(""), m_align(TT_LAYOUT_MAP_HEADER_OFF) {}
   bool defined();
@@ -507,7 +528,7 @@ class thlayout : public thdataobject {
   double scale, scale_bar, base_scale, ox, oy, oz, hsize, vsize, paphs, papvs, paghs, pagvs, marls, marts, gxs, gys, gzs, gox, goy, goz, navf, overlap, opacity,
     map_header_x, map_header_y, legend_width, surface_opacity, rotate;
   
-  char * olx, * oly, 
+  const char * olx, * oly, 
     * doc_title, * doc_comment, * doc_author, * doc_subject, * doc_keywords, * excl_list;
   
   unsigned navsx, navsy, ownp, legend_columns;
@@ -515,7 +536,7 @@ class thlayout : public thdataobject {
   char grid, ccode;
   
   int legend, color_legend, map_header, lang, north, max_explos, max_topos, max_cartos, max_copys,
-    debug, survey_level, surface;
+    debug, survey_level, surface, grid_coords;
   
   thlayout_color color_map_bg, color_map_fg, color_preview_below, color_preview_above;
   int color_crit, // none, altitude, ...
@@ -526,7 +547,7 @@ class thlayout : public thdataobject {
   thlayoutln * first_line, * last_line;
   
   bool titlep, transparency, layers, pgsnum, lock, excl_pages, page_grid, 
-    explo_lens, topo_lens, map_header_bg, sketches;
+    explo_lens, topo_lens, map_header_bg, sketches, color_labels;
 		
 	thlocale units;
 
@@ -543,7 +564,7 @@ class thlayout : public thdataobject {
     def_map_header, def_lang, def_scale_bar, def_map_header_bg,
     def_max_explos, def_max_topos, def_max_cartos,
     def_max_copys, def_explo_lens, def_topo_lens, def_debug, def_survey_level, def_surface,
-    def_surface_opacity, def_units;
+    def_surface_opacity, def_units, def_grid_coords, def_color_labels;
     
   
   thlayout_copy_src * first_copy_src, * last_copy_src;
@@ -573,7 +594,7 @@ class thlayout : public thdataobject {
    * Return class name.
    */
    
-  virtual char * get_class_name() {return "thlayout";};
+  virtual const char * get_class_name() {return "thlayout";};
   
   
   /**
@@ -594,21 +615,21 @@ class thlayout : public thdataobject {
    * Return command name.
    */
    
-  virtual char * get_cmd_name();
+  virtual const char * get_cmd_name();
   
   
   /**
    * Return command end option.
    */
    
-  virtual char * get_cmd_end();
+  virtual const char * get_cmd_end();
   
   
   /**
    * Return option description.
    */
    
-  virtual thcmd_option_desc get_cmd_option_desc(char * opts);
+  virtual thcmd_option_desc get_cmd_option_desc(const char * opts);
   thcmd_option_desc get_default_cod(int id);
   
   /**
