@@ -26,11 +26,17 @@
 ## --------------------------------------------------------------------
 
 
-xth_about_status "loading compiler..."
+xth_about_status [mc "loading compiler..."]
+
+
+proc xth_xcfg_fname {fpath} {
+  return ".xtherion.dat"
+}
 
 
 proc xth_cp_new_file {} {
   global xth
+  xth_status_bar_status cp ""
   if {$xth(cp,fopen)} {
     return
   }
@@ -56,6 +62,7 @@ proc xth_cp_new_file {} {
 
 proc xth_cp_open_file {fpath} {
   global xth
+  xth_status_bar_status cp ""
   
   if {$xth(cp,fopen)} {
     return
@@ -84,25 +91,25 @@ proc xth_cp_open_file {fpath} {
 
   # read the file
   xth_status_bar_push cp
-  xth_status_bar_status cp "Opening $fpath ..."
+  xth_status_bar_status cp [format [mc "Opening %s ..."] $fpath]
 
   set fdata [xth_me_read_file $fpath 0]
   if {[lindex $fdata 0] == 0} {
       MessageDlg $xth(gui,message) -parent $xth(gui,main) \
-        -icon error -type ok \
-        -message [lindex $fdata 1] \
-        -font $xth(gui,lfont)
+	-icon error -type ok \
+	-message [lindex $fdata 1] \
+	-font $xth(gui,lfont)
       xth_status_bar_pop cp
       return 0
   }
   
   # now let's show the file
   catch {
-    set fid [open [file join [file dirname $fpath] ".xth-[file tail $fpath]"] r]
+    set fid [open [file join [file dirname $fpath] [xth_xcfg_fname $fpath]] r]
     fconfigure $fid -encoding utf-8
     while {![eof $fid]} {
       catch {
-        eval [gets $fid]
+	eval [gets $fid]
       }
     }
     close $fid
@@ -138,11 +145,11 @@ proc xth_cp_open_file {fpath} {
 
   $xth(ctrl,cp,info).txt configure -state normal
   
-  $xth(cp,menu,file) entryconfigure "New" -state disabled
-  $xth(cp,menu,file) entryconfigure "Open" -state disabled
-  $xth(cp,menu,file) entryconfigure "Save as" -state normal
-  $xth(cp,menu,file) entryconfigure "Close" -state normal
-  $xth(cp,menu) entryconfigure "Edit" -state normal
+  $xth(cp,menu,file) entryconfigure [mc "New"] -state disabled
+  $xth(cp,menu,file) entryconfigure [mc "Open"] -state disabled
+  $xth(cp,menu,file) entryconfigure [mc "Save as"] -state normal
+  $xth(cp,menu,file) entryconfigure [mc "Close"] -state normal
+  $xth(cp,menu) entryconfigure [mc "Edit"] -state normal
   
   xth_app_title cp
   xth_status_bar_pop cp
@@ -196,11 +203,11 @@ proc xth_cp_close_file {} {
   $xth(cp,log).txt see 1.0
   $xth(cp,log).txt configure -state disabled
 
-  $xth(cp,menu,file) entryconfigure "New" -state normal
-  $xth(cp,menu,file) entryconfigure "Open" -state normal
-  $xth(cp,menu,file) entryconfigure "Save as" -state disabled
-  $xth(cp,menu,file) entryconfigure "Close" -state disabled
-  $xth(cp,menu) entryconfigure "Edit" -state disabled
+  $xth(cp,menu,file) entryconfigure [mc "New"] -state normal
+  $xth(cp,menu,file) entryconfigure [mc "Open"] -state normal
+  $xth(cp,menu,file) entryconfigure [mc "Save as"] -state disabled
+  $xth(cp,menu,file) entryconfigure [mc "Close"] -state disabled
+  $xth(cp,menu) entryconfigure [mc "Edit"] -state disabled
   
   $xth(ctrl,cp,stp).wl configure -state disabled
   $xth(ctrl,cp,stp).we configure -state disabled
@@ -240,18 +247,18 @@ proc xth_cp_write_file {pth} {
   global errorInfo xth
 
   xth_status_bar_push cp
-  xth_status_bar_status cp "Saving $pth ..."
+  xth_status_bar_status cp [format [mc "Saving %s ..."] $pth]
 
   if {[catch {set fid [open $pth w]}]} {
     MessageDlg $xth(gui,message) -parent $xth(gui,main) \
-        -icon error -type ok \
-        -message $errorInfo \
-        -font $xth(gui,lfont)    
+	-icon error -type ok \
+	-message $errorInfo \
+	-font $xth(gui,lfont)    
     xth_status_bar_pop cp
     return 0
   }
 
-  fconfigure $fid -encoding utf-8 -translation {auto lf}
+  fconfigure $fid -encoding utf-8 -translation {auto auto}
   puts $fid "encoding  utf-8"
 
   # let's put data
@@ -285,7 +292,7 @@ proc xth_cp_save_as {} {
   set fname [tk_getSaveFile -filetypes $xth(app,cp,filetypes) \
     -parent $xth(gui,main) \
     -initialfile [file tail $fname] \
-    -initialdir [file dirname $fname]]
+    -initialdir [xth_getdir $fname]]
 
   if {[string length $fname] == 0} {
     return 0
@@ -338,9 +345,9 @@ proc xth_cp_read_file {pth} {
       set rxp "\\s+($enc)\\s+"
       set validenc [regexp -nocase $rxp $xth(encodings) dum curenc]
       if {$validenc == 0} {
-        set success 0
-        set nm "$pth \[$flnn\] -- unknown encoding -- $enc"
-        break
+	set success 0
+	set nm "$pth \[$flnn\] -- unknown encoding -- $enc"
+	break
       }
       fconfigure $fid -encoding $curenc
       set lastln ""
@@ -349,12 +356,12 @@ proc xth_cp_read_file {pth} {
       set lastln ""
     } else {
       if {[regexp {(.*)\\\s*$} $lastln dumln prevln]} {
-        set fln "$prevln$fln"
-        if {[llength $lns] > 1} {
-          set lns [lrange $lns 0 [expr [llength $lns] - 2]]
-        } else {
-          set lns {}
-        }
+	set fln "$prevln$fln"
+	if {[llength $lns] > 1} {
+	  set lns [lrange $lns 0 [expr [llength $lns] - 2]]
+	} else {
+	  set lns {}
+	}
       }
       lappend lns $fln
       set lastln $fln
@@ -368,25 +375,6 @@ proc xth_cp_read_file {pth} {
 
 proc xth_cp_is_config_file {fname} {
   set str {}
-  if {[regexp {\.pdf$} $fname]} {
-    catch {
-      set str {not a config file}
-      set fid [open $fname r]
-      fconfigure $fid -eofchar {}
-      set allstr [read $fid]
-      close $fid
-      if {[regexp {\s+\/TeXsetup\s+\/([0-9a-fA-F]+)\s+} $allstr dum wstr]} {
-        set str {}
-        set i 0
-        while {[string length $wstr] > 0} {
-          set n "0x[string range $wstr 0 1]"
-          append str [format "%c" [expr (255 - $n + $i) % 256]]
-          set wstr [string range $wstr 2 end]
-          incr i
-        }
-      }
-    }
-  }
   return $str
 }
 
@@ -406,35 +394,115 @@ proc xth_cp_compile {} {
   $xth(cp,log).txt configure -wrap word
   $xth(cp,editor).txt configure -state disabled
   xth_status_bar_push cp
-  xth_status_bar_status cp "Running therion ..."
-  $xth(ctrl,cp,stp).gores configure -text "RUNNING" -fg black -bg yellow
+  
+  catch {
+    set lid [open "therion.log" w]
+    puts $lid "ERROR: Can not execute \"$xth(gui,compcmd) -x $xth(cp,opts) $xth(cp,fname)\"."
+    close $lid
+  }  
+
+  set acroreadopen 1
+  if {[llength $xth(cp,preview,acroreadpath)] > 0 } {
+    catch {
+      set acroreadopen [catch {
+	exec $xth(gui,appctrlcmd) ARExists [file join $xth(cp,fpath) $xth(cp,preview,acroreadpath)]
+      }]
+    }
+    if {!$acroreadopen} {
+      catch {
+	exec $xth(gui,appctrlcmd) AROpen [file join $xth(cp,fpath) $xth(cp,preview,acroreadpath)]
+	exec $xth(gui,appctrlcmd) ARClose [file join $xth(cp,fpath) $xth(cp,preview,acroreadpath)]
+      }
+    }
+  }
+
+  
+  xth_status_bar_status cp [mc "Running therion ..."]
+  $xth(ctrl,cp,stp).gores configure -text [mc "RUNNING"] -fg black -bg yellow
   update idletasks
-  set err [catch {
+  catch {
     set thid [open "|$xth(gui,compcmd) -x $xth(cp,opts) $xth(cp,fname)" r]
     if $xth(gui,compshow) {
       while {![eof $thid]} {
-        $xth(cp,log).txt insert end [read $thid 8]
-        $xth(cp,log).txt see end
-        update idletasks
+	$xth(cp,log).txt insert end [read $thid 8]
+	$xth(cp,log).txt see end
+	update idletasks
       }
     } else {
       read $thid;
     }
     close $thid
-  }]
+  }
   
   set see_end 0
+  
+  #puts $err
+  #global errorInfo
+  #puts $errorInfo
+
+  # update UI
+  xth_cp_data_tree_clear      
+  set xth(th_exit_state) 0
+  set xth(th_exit_number) $xth(th_exit_number_last)
+  set dat_loaded_err [catch {
+    set fid [open [file join [file dirname $xth(cp,ffull)] [xth_xcfg_fname $xth(cp,ffull)]] r]
+    fconfigure $fid -encoding utf-8
+    while {![eof $fid]} {
+      catch {eval [gets $fid]}
+    }
+    close $fid
+  }]
+
+  set err 0
+  if {$dat_loaded_err} {
+    set err 1
+  }
+  if {$xth(th_exit_number) == $xth(th_exit_number_last)} {
+    set err 1
+  } else {
+    set xth(th_exit_number_last) $xth(th_exit_number)
+  }
+  if {$xth(th_exit_state) == 0} {
+    set err 1
+  }
+
+  
   if {$err} {
     bell
-    $xth(ctrl,cp,stp).gores configure -text "ERROR" -fg white -bg red
+    $xth(ctrl,cp,stp).gores configure -text [mc "ERROR"] -fg white -bg red
     set ret 0
     set see_end 1
   } else {
     set xth(cp,compres) 1
-    $xth(ctrl,cp,stp).gores configure -text "OK" -fg black -bg green
+    if {$xth(gui,auto_backup)} {
+      xth_cp_write_file "$xth(cp,ffull)$xth(gui,auto_backup_ext)"
+    }
+
+    if {$xth(th_exit_state) == 1} {
+      bell
+      $xth(ctrl,cp,stp).gores configure -text [mc "WARNING"] -fg black -bg orange
+    } else {
+      $xth(ctrl,cp,stp).gores configure -text [mc "OK"] -fg black -bg green
+    }
+
+    if { [llength $xth(cp,preview,xpdfpath)] > 0 } {
+      catch {
+	exec xpdf -remote thpdf [file join $xth(cp,fpath) $xth(cp,preview,xpdfpath)] &
+      }
+    }
+    if { [llength $xth(cp,preview,acroreadpath)] > 0 } {
+      catch {
+	if {$acroreadopen} {
+	  exec $xth(gui,appctrlcmd) AROpen [file join $xth(cp,fpath) $xth(cp,preview,acroreadpath)]
+	} else {
+	  exec $xth(gui,appctrlcmd) ARBack [file join $xth(cp,fpath) $xth(cp,preview,acroreadpath)]
+	}
+      }
+    }
+
   }
   
-  xth_status_bar_status cp "Reading therion log file ..."
+  xth_status_bar_status cp [mc "Reading therion log file ..."]
   if {[catch {
     set lid [open "therion.log" r]
     $xth(cp,log).txt delete 1.0 end
@@ -442,7 +510,7 @@ proc xth_cp_compile {} {
     $xth(cp,log).txt insert end "[read $lid]\n"
     close $lid
     }]} {
-      $xth(cp,log).txt insert end "\nerror opening therion.log file\n"
+      $xth(cp,log).txt insert end [mc "\nerror opening therion.log file\n"]
   }
   if ($see_end) {
     $xth(cp,log).txt see end
@@ -455,41 +523,39 @@ proc xth_cp_compile {} {
   $xth(cp,log).txt configure -state normal
   $xth(cp,editor).txt configure -state normal
   xth_cp_show_errors
-
+  
   # update configuration file if required
   set xth(cp,cursor) [$xth(cp,editor).txt index insert]
-  if {1} {
+  if {0} {
     set fdata [xth_me_read_file $xth(cp,ffull) 0]
     if {[lindex $fdata 0] == 0} {
-        MessageDlg $xth(gui,message) -parent $xth(gui,main) \
-          -icon error -type ok \
-          -message [lindex $fdata 1] \
-          -font $xth(gui,lfont)
+	MessageDlg $xth(gui,message) -parent $xth(gui,main) \
+	  -icon error -type ok \
+	  -message [lindex $fdata 1] \
+	  -font $xth(gui,lfont)
     } else {
-      xth_cp_data_tree_clear      
+      ###xth_cp_data_tree_clear      
 
-      catch {
-        set fid [open [file join [file dirname $xth(cp,ffull)] ".xth-[file tail $xth(cp,ffull)]"] r]
-        fconfigure $fid -encoding utf-8
-        while {![eof $fid]} {
-          catch {eval [gets $fid]}
-        }
-        close $fid
-      }
 
       set xth(cp,special) [lindex $fdata 2]
+     
+      $xth(cp,editor).txt configure -undo 0 
       
       $xth(cp,editor).txt delete 1.0 end
       foreach ln [lindex $fdata 3] {
-        $xth(cp,editor).txt insert end "$ln\n"
+	$xth(cp,editor).txt insert end "$ln\n"
       }
       
       $xth(cp,editor).txt mark set insert $xth(cp,cursor)
       $xth(cp,editor).txt see $xth(cp,cursor)
       
+      $xth(cp,editor).txt configure -undo 1
+      
     }
   }
   cd $cdir
+  xth_me_xvi_refresh
+  xth_me_save_file 0
   return $ret
 }
 
@@ -546,7 +612,7 @@ proc xth_cp_data_tree_create {} {
     return
   }
   set nlist [lsort -dictionary -index 0 $xth(ctrl,cp,datlist)]
-  set level 0
+  set level 1
   set tocnt 1
   set copen 1
   set tp $xth(ctrl,cp,dat).t 
@@ -554,18 +620,18 @@ proc xth_cp_data_tree_create {} {
     set tocnt 0
     foreach di $nlist {
       if {[lindex $di 3] == $level} {
-        if {$level == 0} {
-          set parent root
-        } else {
-          set parent [lindex $di 2]
-        }
-        catch {
-          $tp insert end $parent [lindex $di 1] -data [list survey [lindex $di 5] [lindex $di 6] [lindex $di 7]] \
-            -text [lindex $di 6] -image [Bitmap::get folder] -open $copen -font $xth(gui,lfont)
-        }
+	if {$level == 1} {
+	  set parent root
+	} else {
+	  set parent [lindex $di 2]
+	}
+	catch {
+	  $tp insert end $parent [lindex $di 1] -data [list survey [lindex $di 5] [lindex $di 6] [lindex $di 7]] \
+	    -text [lindex $di 6] -image [Bitmap::get folder] -open $copen -font $xth(gui,lfont)
+	}
       }
       if {[lindex $di 3] > $level} {
-        set tocnt 1
+	set tocnt 1
       }
     }
     set copen 0
@@ -599,35 +665,35 @@ proc xth_cp_map_tree_create {} {
     set tocnt 0
     foreach di $nlist {
       if {[lindex $di 3] == $level} {
-        if {$level == 0} {
-          set parent root
-        } else {
-          set parent [lindex $di 2]
-        }
-        set ccopen $copen
-        switch [lindex $di 7] {
-          map {
-            if {[lindex $di 8]} {
-              set ii [Bitmap::get file]
-              set ccopen 0
-            } else {
-              set ii [Bitmap::get copy]
-            }
-          }
-          scrap {
-            set ii [Bitmap::get new]
-          }
-          default {
-            set ii [Bitmap::get folder]
-          } 
-        }
-        catch {
-          $tp insert end $parent [lindex $di 1] -data [list [lindex $di 7] [lindex $di 5] [lindex $di 6]] \
-            -text [lindex $di 6] -image $ii -open $ccopen -font $xth(gui,lfont)
-        }
+	if {$level == 0} {
+	  set parent root
+	} else {
+	  set parent [lindex $di 2]
+	}
+	set ccopen $copen
+	switch [lindex $di 7] {
+	  map {
+	    if {[lindex $di 8]} {
+	      set ii [Bitmap::get file]
+	      set ccopen 0
+	    } else {
+	      set ii [Bitmap::get copy]
+	    }
+	  }
+	  scrap {
+	    set ii [Bitmap::get new]
+	  }
+	  default {
+	    set ii [Bitmap::get folder]
+	  } 
+	}
+	catch {
+	  $tp insert end $parent [lindex $di 1] -data [list [lindex $di 7] [lindex $di 5] [lindex $di 6]] \
+	    -text [lindex $di 6] -image $ii -open $ccopen -font $xth(gui,lfont)
+	}
       }
       if {[lindex $di 3] > $level} {
-        set tocnt 1
+	set tocnt 1
       }
     }
     set copen 0
@@ -640,10 +706,10 @@ proc xth_cp_map_tree_create {} {
     set nds [$tp nodes $prj]
     switch [llength $nds] {
       0 {
-        $tp delete $prj
+	$tp delete $prj
       }
       1 {
-        $tp itemconfigure $nds -open 1
+	$tp itemconfigure $nds -open 1
       }
     }
   }
@@ -791,8 +857,8 @@ proc xth_cp_goto_error {x y} {
     # skusime textovy editor, ci to mame otvorene
     foreach fx $xth(te,flist) {
       if {[string equal $fullfnm $xth(te,$fx,path)]} {
-        after idle "xth_app_show te; xth_te_show_file $fx; $xth(te,$fx,frame).txt see $fln.0; $xth(te,$fx,frame).txt mark set insert $fln.0; $xth(te,$fx,frame).txt tag remove sel 1.0 end; $xth(te,$fx,frame).txt tag add sel $fln.0 \"$fln.0 lineend\""
-        return
+	after idle "xth_app_show te; xth_te_show_file $fx; $xth(te,$fx,frame).txt see $fln.0; $xth(te,$fx,frame).txt mark set insert $fln.0; $xth(te,$fx,frame).txt tag remove sel 1.0 end; $xth(te,$fx,frame).txt tag add sel $fln.0 \"$fln.0 lineend\""
+	return
       }
     }
     
